# Tutorials

::::{grid} 1 1 2 2
:gutter: 3

:::{grid-item-card} Quickstart
:link: quickstart
:link-type: doc
Learn to resample scattered point data onto a HEALPix grid in four steps.
:::

:::{grid-item-card} 4 resamplers
:link: 4resamplers
:link-type: doc
Learn how four resampling methods compare in behaviour, accuracy, and speed on the same dataset.
:::
::::

```{toctree}
:hidden:
:maxdepth: 1

quickstart
4resamplers
```
